@@ -53,7 +53,8 @@
 #pod
 #pod =head1 DESCRIPTION
 #pod
-#pod
+#pod The role provides consuming plugin with C<fill_in_string> method and bunch of accompanying
+#pod attributes and F<dist.ini> options.
 #pod
 #pod =cut
 
@@ -63,9 +64,9 @@ use Moose::Role;
 use namespace::autoclean;
 
 # ABSTRACT: Have text templating capabilities in your Dist::Zilla plugin
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
-with 'Dist::Zilla::Role::ErrorLogger';
+with 'Dist::Zilla::Role::ErrorLogger' => { -version => 0.005 };
 
 use Text::Template qw{};
 
@@ -75,7 +76,10 @@ use Text::Template qw{};
 #pod
 #pod Pair of open and closing delimiters the code fragments surrounded by.
 #pod
-#pod ArrayRef[Str], read-only, not an init argument (yet). Default value is '{{', '}}'.
+#pod Attribute introduces F<dist.ini> option with the same name. Option value will be split (see
+#pod C<BUILDARGS>) to initialize the attribute.
+#pod
+#pod ArrayRef[Str], read-only. Default value is '{{', '}}'.
 #pod
 #pod See C<DELIMITERS> option of L<Text::Template/"fill_in">.
 #pod
@@ -88,7 +92,6 @@ has delimiters => (
   is            => 'ro',
   isa           => 'ArrayRef[Str]',
   lazy          => 1,
-  init_arg      => undef,       # TODO: Let user specify delimiters.
   default       => sub { [ '{{', '}}' ] },
 );
 
@@ -98,6 +101,8 @@ has delimiters => (
 #pod
 #pod Name of package to evaluate code fragments in.
 #pod
+#pod Attribute introduces F<dist.ini> option with the same name.
+#pod
 #pod Str, read-only, optional.
 #pod
 #pod See C<PACKAGE> option of L<Text::Template/"fill_in">.
@@ -116,6 +121,8 @@ has package => (
 #pod
 #pod Perl code to prepend to the beginning of every code fragment.
 #pod
+#pod Attribute introduces F<dist.ini> multi-value option with the same name.
+#pod
 #pod ArrayRef[Str], read-only, auto dereferenced. Default value is empty array. Another default value
 #pod may be specified by defining C<_build_prepend> method.
 #pod
@@ -181,6 +188,31 @@ sub _build_broken {
     };
 };
 
+# --------------------------------------------------------------------------------------------------
+
+#pod =Method BUILDARGS
+#pod
+#pod The method splits C<delimiters> option value into list of words to initialize C<delimiters>
+#pod attribute (which is of C<ArrayRef[Str]> type).
+#pod
+#pod =cut
+
+around BUILDARGS => sub {
+    my ( $orig, $class, $args ) = @_;
+    if ( exists( $args->{ delimiters } ) ) {
+        $args->{ delimiters } = [ split( m{\s+}, $args->{ delimiters } ) ];
+    };
+    return $class->$orig( $args );
+};
+
+# --------------------------------------------------------------------------------------------------
+
+#pod =method mvp_multivalue_args
+#pod
+#pod The method tells C<Dist::Zilla> that C<prepend> is a multi-value option.
+#pod
+#pod =cut
+
 around mvp_multivalue_args => sub {
     my ( $orig, $self ) = @_;
     return ( $self->$orig(), qw{ prepend } );
@@ -193,9 +225,30 @@ around mvp_multivalue_args => sub {
 #pod     $result = $self->fill_in_string( $template, \%variables, \%extra_args );
 #pod     $result = $self->fill_in_string( $template );
 #pod
-#pod
 #pod The primary method of the role.
 #pod
+#pod The interface is compatible with method of C<TextTemplate> role, so this role can be used as a
+#pod drop-in replacement for C<TextTemplate>. However, methods are implemented slightly differently
+#pod (this method calls C<Text::Template::fill_in_string> function, that one creates C<Text::Template>
+#pod object first, then calls C<fill_in> method on the object), it may cause subtle difference in
+#pod behaviour.
+#pod
+#pod Template variables C<$plugin> and C<$dist> are set by default, if not explicitly defined in
+#pod C<\%variables>.
+#pod
+#pod The method calls C<Text::Template::fill_in_string>, passing to it the C<$template>, C<\%variables>,
+#pod attribute values C<package>, C<prepend>, C<broken>, and finally C<%extra_args>. C<%extra_args> is
+#pod passed in the end intentionally, so caller may override any of parameters specified by the method,
+#pod for example:
+#pod
+#pod     $self->fill_in_string( $template, undef, { package => 'MY' } );
+#pod         #   Execute code fragments in package MY regardless of $self->package value.
+#pod
+#pod It also allows to cancel defining C<$plugin> and C<$dist> variables, e. g.:
+#pod
+#pod     $self->fill_in_string( $template, undef, { hash => {} } );
+#pod         #   Do not define any variables for the template.
+#pod
 #pod =cut
 
 sub fill_in_string {
@@ -206,7 +259,6 @@ sub fill_in_string {
         $hash ? %$hash : (),
     );
     my @args = (
-        $string,
         hash       => \%hash,
         delimiters => $self->delimiters,
         $self->package ? ( package => $self->package,              ) : (),
@@ -225,7 +277,7 @@ sub fill_in_string {
             chomp( $msg );
             $self->log( $msg );
         };
-        $result = Text::Template::fill_in_string( @args );
+        $result = Text::Template::fill_in_string( $string, @args );
     }
     if ( not defined( $result ) ) {
         $self->log_error( $Text::Template::ERROR );
@@ -240,6 +292,29 @@ sub fill_in_string {
 
 # --------------------------------------------------------------------------------------------------
 
+#pod =head1 NOTES
+#pod
+#pod =head2 C<Text::Template> option spelling
+#pod
+#pod C<Text::Template> allows a programmer to use different spelling of options: all-caps, first-caps,
+#pod all-lowercase, with and without leading dash, e. g.: C<HASH>, C<Hash>, C<hash>, C<-HASH>, C<-Hash>,
+#pod C<-hash>. This is documented feature.
+#pod
+#pod C<Text::Template> recommends to pick a style and stick with it. (BTW, C<Text::Template>
+#pod documentation itself uses all-caps spelling.) This role picked all-lowercase style. This choice
+#pod have subtle consequences. Let us consider an example:
+#pod
+#pod     $self->fill_in_string( $template, undef, { PACKAGE => 'MY' } );
+#pod
+#pod Extra option C<PACKAGE> may or may not not have effect, depending on value of C<package> attribute
+#pod (i. e. presence or absence C<package> option in F<dist.ini> file), because (this is not documented)
+#pod spellings are not equal: different spellings have different priority. If C<PACKAGE> and C<package>
+#pod are specified simultaneously, C<package> wins, C<PACKAGE> loses.
+#pod
+#pod This feature gives you a choice. If you want to ignore option specified by the user in F<dist.ini>
+#pod and provide your value, use all-lowercase option name. If you want to provide default which can be
+#pod overridden by the user, use all-caps options name.
+#pod
 #pod =head1 SEE ALSO
 #pod
 #pod L<Dist::Zilla>
@@ -345,7 +420,7 @@ Dist::Zilla::Role::TextTemplater - Have text templating capabilities in your Dis
 
 =head1 VERSION
 
-Version 0.001, released on 2015-07-14 21:52 UTC.
+Version 0.002, released on 2015-07-18 18:38 UTC.
 
 =head1 WHAT?
 
@@ -380,13 +455,26 @@ reporting and some others are covered in the L<readme|Dist::Zilla::Role::TextTem
 
 =head1 DESCRIPTION
 
+The role provides consuming plugin with C<fill_in_string> method and bunch of accompanying
+attributes and F<dist.ini> options.
+
+=head1 CLASS METHODS
+
+=head2 BUILDARGS
+
+The method splits C<delimiters> option value into list of words to initialize C<delimiters>
+attribute (which is of C<ArrayRef[Str]> type).
+
 =head1 OBJECT ATTRIBUTES
 
 =head2 delimiters
 
 Pair of open and closing delimiters the code fragments surrounded by.
 
-ArrayRef[Str], read-only, not an init argument (yet). Default value is '{{', '}}'.
+Attribute introduces F<dist.ini> option with the same name. Option value will be split (see
+C<BUILDARGS>) to initialize the attribute.
+
+ArrayRef[Str], read-only. Default value is '{{', '}}'.
 
 See C<DELIMITERS> option of L<Text::Template/"fill_in">.
 
@@ -397,6 +485,8 @@ delimiters with backslash does not work. See L<Text::Template/"Alternative Delim
 
 Name of package to evaluate code fragments in.
 
+Attribute introduces F<dist.ini> option with the same name.
+
 Str, read-only, optional.
 
 See C<PACKAGE> option of L<Text::Template/"fill_in">.
@@ -405,6 +495,8 @@ See C<PACKAGE> option of L<Text::Template/"fill_in">.
 
 Perl code to prepend to the beginning of every code fragment.
 
+Attribute introduces F<dist.ini> multi-value option with the same name.
+
 ArrayRef[Str], read-only, auto dereferenced. Default value is empty array. Another default value
 may be specified by defining C<_build_prepend> method.
 
@@ -422,6 +514,10 @@ See C<BROKEN> option of L<Text::Template/"fill_in">.
 
 =head1 OBJECT METHODS
 
+=head2 mvp_multivalue_args
+
+The method tells C<Dist::Zilla> that C<prepend> is a multi-value option.
+
 =head2 fill_in_string
 
     $result = $self->fill_in_string( $template, \%variables, \%extra_args );
@@ -429,6 +525,51 @@ See C<BROKEN> option of L<Text::Template/"fill_in">.
 
 The primary method of the role.
 
+The interface is compatible with method of C<TextTemplate> role, so this role can be used as a
+drop-in replacement for C<TextTemplate>. However, methods are implemented slightly differently
+(this method calls C<Text::Template::fill_in_string> function, that one creates C<Text::Template>
+object first, then calls C<fill_in> method on the object), it may cause subtle difference in
+behaviour.
+
+Template variables C<$plugin> and C<$dist> are set by default, if not explicitly defined in
+C<\%variables>.
+
+The method calls C<Text::Template::fill_in_string>, passing to it the C<$template>, C<\%variables>,
+attribute values C<package>, C<prepend>, C<broken>, and finally C<%extra_args>. C<%extra_args> is
+passed in the end intentionally, so caller may override any of parameters specified by the method,
+for example:
+
+    $self->fill_in_string( $template, undef, { package => 'MY' } );
+        #   Execute code fragments in package MY regardless of $self->package value.
+
+It also allows to cancel defining C<$plugin> and C<$dist> variables, e. g.:
+
+    $self->fill_in_string( $template, undef, { hash => {} } );
+        #   Do not define any variables for the template.
+
+=head1 NOTES
+
+=head2 C<Text::Template> option spelling
+
+C<Text::Template> allows a programmer to use different spelling of options: all-caps, first-caps,
+all-lowercase, with and without leading dash, e. g.: C<HASH>, C<Hash>, C<hash>, C<-HASH>, C<-Hash>,
+C<-hash>. This is documented feature.
+
+C<Text::Template> recommends to pick a style and stick with it. (BTW, C<Text::Template>
+documentation itself uses all-caps spelling.) This role picked all-lowercase style. This choice
+have subtle consequences. Let us consider an example:
+
+    $self->fill_in_string( $template, undef, { PACKAGE => 'MY' } );
+
+Extra option C<PACKAGE> may or may not not have effect, depending on value of C<package> attribute
+(i. e. presence or absence C<package> option in F<dist.ini> file), because (this is not documented)
+spellings are not equal: different spellings have different priority. If C<PACKAGE> and C<package>
+are specified simultaneously, C<package> wins, C<PACKAGE> loses.
+
+This feature gives you a choice. If you want to ignore option specified by the user in F<dist.ini>
+and provide your value, use all-lowercase option name. If you want to provide default which can be
+overridden by the user, use all-caps options name.
+
 =head1 WHY?
 
 C<TextTemplate> role from C<Dist::Zilla> distribution v5.037 has the same great C<Text::Template>
